==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/tasks/language/nl.php <==
<?php


$l['name']='Taken';
$l['description']='Taken module';
$lang['link_type'][12]=$l['task']='Taak';
$l['status']='Status';
$l['scheduled_call']='Telefoongesprek gepland op %s';
$l['statuses']['NEEDS-ACTION']='Actie nodig';
$l['statuses']['ACCEPTED']='Geaccepteerd';
$l['statuses']['DECLINED']='Geweigerd';
$l['statuses']['TENTATIVE']='Voorlopig';
$l['statuses']['DELEGATED']='Gedelegeerd';
$l['statuses']['COMPLETED']='Voltooid';
$l['statuses']['IN-PROCESS']='Wordt aan gewerkt';
$l['call']='Bellen';
$l['import_success']='%s taken werden geïmporteerd';
$l['dueAtdate']='Verloopt op %s';
$l['list']='Takenlijst';
$l['tasklistChanged']="* Takenlijst is veranderd van '%s' naar '%s'";
$l['statusChanged']="* Status is veranderd van'%s' naar '%s'";
$l['multipleSelected']='Meerdere takenlijsten geselecteerd';
$l['incomplete_delete']='U heeft niet voldoende rechten om alle geselecteerde taken te verwijderen';$l["task"]= 'Taak';
$l["noTask"]= 'Geen taken om weer te geven';
$l["tasks"]= 'Taken';
$l["addTask"]= 'Taak toevoegen...';
$l["tasklist"]= 'Takenlijst';
$l["tasklists"]= 'Takenlijsten';
$l["showCompletedTasks"]= 'Toon voltooide taken';
$l["filter"]= 'Filter';
$l["dueDate"]= 'Einddatum';
$l["dueAt"]= 'Verloopt op';
$l["needsAction"]= 'Actie vereist';
$l["accepted"]= 'Geaccepteerd';
$l["declined"]= 'Afgewezen';
$l["tentative"]= 'Voorlopig';
$l["delegated"]= 'Gedelegeerd';
$l["completed"]= 'Voltooid';
$l["inProcess"]= 'Bezig';
$l["repeatEvery"]= 'Herhaal iedere';
$l["atDays"]= 'Op dagen';
$l["repeatUntil"]= 'Herhaal totdat';
$l["repeatForever"]= 'herhaal altijd';
$l["recurrence"]= 'Herhaling';
$l["remindMe"]= 'Herinner mij';
$l["options"]= 'Opties';
$l["createLink"]= 'Maak een koppeling';
$l["startsAt"]='Start op';
$l["completedAt"]='Voltooid op';
$l["showInactiveTasks"]='Toon inactive taken';
$l["scheduleCall"]='Telefoongesprek plannen';
$l["call"]='Bellen';
$l["taskDefaults"]='Standaard instellingen voor taken';
$l["daysBeforeStart"]='Dagen voor aanvang';
$l["defaultTasklist"]='Standaard takenlijst';
$l["visibleTasklists"]='Zichtbare taaklijsten';
$l["visible"]='Zichtbaar';
$l["selectIcalendarFile"]='Selecteer een icalendar (*.ics) bestand';
$l["continueTask"]='Vervolg taak';
$l["categories"]='Categorieen';
$l["category"]='Categorie';
$l["selectCategory"]='Selecteer categorie';
$l["noTasklistSelected"]='U dient minimaal 1 takenlijst te selecteren.';
$l["selectAllTasklists"]='Selecteer alle takenlijsten';
$l["globalCategory"]='Globale category';
$l["showFutureTasks"]='Toon toekomstige taken';
$l["incompleteTasks"]='Onvoltooide taken';
$l["dueInSevenDays"]='Eindigt komende week';
$l["overDue"]='Te laat';
$l["futureTasks"]='Toekomstige taken';
$l["all"]='Alles';
$l["active"]='Actieve';
$l["globalsettings_templatelabel"]='Naam template';
$l["globalsettings_allchangelabel"]='Bestaande veranderen?';
$l["globalsettings_renameall"]= 'Weet u zeker dat u alles wilt hernoemen?';

$l['taskPercentage_complete']='Percentage voltooid';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/tasks/language/nl.php <==
<?php


$l['name']='Taken';
$l['description']='Taken module';
$l['status']='Status';
$l['scheduled_call']='Telefoongesprek gepland op %s';
$l['statuses']['NEEDS-ACTION']='Actie nodig';
$l['statuses']['ACCEPTED']='Geaccepteerd';
$l['statuses']['DECLINED']='Geweigerd';
$l['statuses']['TENTATIVE']='Voorlopig';
$l['statuses']['DELEGATED']='Gedelegeerd';
$l['statuses']['COMPLETED']='Voltooid';
$l['statuses']['IN-PROCESS']='Wordt aan gewerkt';
$l['call']='Bellen';
$l['import_success']='%s taken werden geïmporteerd';
$l['dueAtdate']='Verloopt op %s';
$l['list']='Takenlijst';
$l['tasklistChanged']="* Takenlijst is veranderd van '%s' naar '%s'";
$l['statusChanged']="* Status is veranderd van'%s' naar '%s'";
$l['multipleSelected']='Meerdere takenlijsten geselecteerd';
$l['incomplete_delete']='U heeft niet voldoende rechten om alle geselecteerde taken te verwijderen';
$l["noTask"]= 'Geen taken om weer te geven';
$l["tasks"]= 'Taken';
$l["addTask"]= 'Taak toevoegen...';
$l["tasklist"]= 'Takenlijst';
$l["tasklists"]= 'Takenlijsten';
$l["showCompletedTasks"]= 'Toon voltooide taken';
$l["filter"]= 'Filter';
$l["dueDate"]= 'Einddatum';
$l["dueAt"]= 'Verloopt op';
$l["needsAction"]= 'Actie vereist';
$l["accepted"]= 'Geaccepteerd';
$l["declined"]= 'Afgewezen';
$l["tentative"]= 'Voorlopig';
$l["delegated"]= 'Gedelegeerd';
$l["completed"]= 'Voltooid';
$l["inProcess"]= 'Bezig';
$l["repeatEvery"]= 'Herhaal iedere';
$l["atDays"]= 'Op dagen';
$l["repeatUntil"]= 'Herhaal totdat';
$l["repeatForever"]= 'herhaal altijd';
$l["recurrence"]= 'Herhaling';
$l["remindMe"]= 'Herinner mij';
$l["options"]= 'Opties';
$l["createLink"]= 'Maak een koppeling';
$l["startsAt"]='Start op';
$l["completedAt"]='Voltooid op';
$l["showInactiveTasks"]='Toon inactive taken';
$l["scheduleCall"]='Telefoongesprek plannen';
$l["call"]='Bellen';
$l["taskDefaults"]='Standaard instellingen voor taken';
$l["daysBeforeStart"]='Dagen voor aanvang';
$l["defaultTasklist"]='Standaard takenlijst';
$l["visibleTasklists"]='Zichtbare taaklijsten';
$l["visible"]='Zichtbaar';
$l["selectIcalendarFile"]='Selecteer een icalendar (*.ics) bestand';
$l["continueTask"]='Vervolg taak';
$l["categories"]='Categorieen';
$l["category"]='Categorie';
$l["selectCategory"]='Selecteer categorie';
$l["noTasklistSelected"]='U dient minimaal 1 takenlijst te selecteren.';
$l["selectAllTasklists"]='Selecteer alle takenlijsten';
$l["globalCategory"]='Globale category';
$l["showFutureTasks"]='Toon toekomstige taken';
$l["incompleteTasks"]='Onvoltooide taken';
$l["dueInSevenDays"]='Eindigt komende week';
$l["overDue"]='Te laat';
$l["futureTasks"]='Toekomstige taken';
$l["all"]='Alles';
$l["active"]='Actieve';
$l["globalsettings_templatelabel"]='Naam template';
$l["globalsettings_allchangelabel"]='Bestaande veranderen?';
$l["globalsettings_renameall"]= 'Weet u zeker dat u alles wilt hernoemen?';

$l['taskPercentage_complete']='Percentage voltooid';

$l["task"]= 'Taak';
$l["taskName"]='Naam';
$l["taskCtime"]='Gemaakt op';
$l["taskMtime"]='Gewijzigd op';
$l["taskDue_time"]='Eindigt op';
$l["taskStatus"]='Status';
$l["taskCompletion_time"]='Voltooid op';
$l["taskProject_name"]='Project';
